My Python Project
==============================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

    intro
    demo
    api

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
